@@ -1,7 +1,7 @@
 package Data::Sah::Params;
 
-our $DATE = '2016-05-26'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-05-30'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -130,7 +130,7 @@ Data::Sah::Params - Validate function arguments using Sah schemas
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Params (from Perl distribution Data-Sah-Params), released on 2016-05-26.
+This document describes version 0.003 of Data::Sah::Params (from Perl distribution Data-Sah-Params), released on 2016-05-30.
 
 =head1 SYNOPSIS
 
@@ -191,13 +191,24 @@ Currently mixing positional and named parameters not yet supported.
 
 =head1 FUNCTIONS
 
-=head2 compile($schema, ...) => coderef
+=head2 compile([ \%opts, ] $schema, ...) => coderef
 
 Create a validator. Accepts a list of schemas. Each schema can be prefixed with
 C<Optional> or C<Slurpy>. Or, if your function will accept named arguments
 (C<%args>) you can use: C<< Named(PARAM1=>$schema1, PARAM2=>$schema2, ...) >>
 instead.
 
+Known options:
+
+=over
+
+=item * want_source => bool
+
+If set to 1, will return validator source code string instead of compiled code
+(coderef). Useful for debugging.
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-Params>.
@@ -224,6 +235,10 @@ If you put your schemas in L<Rinci> function metadata (I recommend it, for the
 convenience of specifying other stuffs besides argument schemas), take a look at
 L<Perinci::Sub::ValidateArgs>.
 
+L<Params::Sah>. I've actually implemented something similar the year before
+(albeit with a slightly different interface), before absent-mindedly
+reimplemented later :-) We'll see which one will thrive.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
